Python: module util

util | index /tmp/makerelease-pwman-python.NVQhFLFA/pwman-python-2.8/libpwman/util.py

# Simple password manager
# Copyright (c) 2011-2023 Michael Büsch <m@bues.ch>
# Licensed under the GNU/GPL version 2 or later.

Modules
curses | getpass | os | sys

Functions
|  | clearScreen() readPassphrase(prompt, verify=False) stdout(text, flush=True) str2bool(string, default=False) uniq(l, sort=True)

Data
|  | __all__ = ['str2bool', 'osIsWindows', 'osIsPosix', 'uniq', 'stdout', 'clearScreen', 'readPassphrase'] osIsPosix = True osIsWindows = False